==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/cs_CZ.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendář",
    "Individual" : "Individuální",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Místnost",
    "Unknown" : "Neznámý",
    "Required" : "Vyžadován",
    "Optional" : "Nepovinně",
    "Does not attend" : "Neúčastní se",
    "New event" : "Nová událost",
    "Attendees" : "Účastníci",
    "Reminders" : "Připomínky",
    "Repeating" : "Opakování",
    "When shared show full event" : "Po nasdílení zobrazit celou událost",
    "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
    "When shared hide this event" : "Po nasdílení skrýt tuto událost",
    "Please add a title!" : "Zadejte prosím název!",
    "Please select a calendar!" : "Vyberte prosím kalendář!",
    "Global" : "Globální",
    "None" : "Žádné",
    "Every day" : "Každý den",
    "Every week" : "Každý týden",
    "Every month" : "Každý měsíc",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "At time of event" : "V čase události",
    "5 minutes before" : "5 minut předem",
    "10 minutes before" : "10 minut předem",
    "15 minutes before" : "15 minut předem",
    "30 minutes before" : "30 minut předem",
    "1 hour before" : "1 hodinu předem",
    "2 hours before" : "2 hodiny předem",
    "Custom" : "Vlastní",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Vyskakovací",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodiny",
    "days" : "dnech",
    "week" : "týden",
    "before" : "před",
    "start" : "začátek",
    "end" : "konec",
    "Editing reminders of uknown type not supported." : "Úprava připomínek neznámého typu není podporována. ",
    "Week {number} of {year}" : "Týden {number} rok {year}",
    "Successfully imported" : "Úspěšně importován",
    "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
    "Partially imported, {n} failures" : "Částečně importován, {n} chyb",
    "Audio alarm" : "Zvuková upomínka",
    "Pop-up" : "Vyskakovací",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} před začátkem události",
    "{type} {time} before the event ends" : "{type} {time} před koncem události",
    "{type} {time} after the event starts" : "{type} {time} po začátku události",
    "{type} {time} after the event ends" : "{type} {time} po konci události",
    "{type} at the event's start" : "{type} při začátku události",
    "{type} at the event's end" : "{type} při konci události",
    "{type} at {time}" : "{type} v {time}",
    "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
    "Title of the Event" : "Název události",
    "starts" : "začíná",
    "ends" : "končí",
    "All day Event" : "Celodenní událost",
    "Location" : "Umístění",
    "Delete" : "Smazat",
    "Cancel" : "Zrušit",
    "More ..." : "Více ...",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Close" : "Zavřít",
    "Description" : "Popis",
    "Export" : "Exportovat",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prosím, kontaktujte Vašeho administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "Today" : "Dnes",
    "Share Calendar" : "Sdílet kalendář",
    "More" : "Více",
    "Edit" : "Upravit",
    "CalDAV" : "CalDAV",
    "group" : "skupina",
    "New Calendar" : "Nový kalendář",
    "Subscriptions" : "Odběry",
    "New Subscription" : "Nový odběr",
    "Url" : "URL",
    "Edit event" : "Upravit událost",
    "Delete Event" : "Smazat událost",
    "Save Event" : "Uložit událost",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relativní",
    "Absolute" : "Absolutní",
    "Repeat" : "Opakovat",
    "times every" : "krát každých",
    "Add" : "Přidat",
    "E-Mail address of attendee" : "Emailová adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pokročilých pravidel bude přidána v následujících aktualizacích.",
    "Reset repeating rule" : "Resetovat pravidlo opakování",
    "Repeat every ..." : "Opakovat každé ...",
    "end repeat ..." : "ukončit opakování ...",
    "times" : "krát",
    "Import Calendars" : "Importovat kalendáře",
    "Import canceled" : "Import zrušen",
    "Analyzing calendar" : "Analýza kalendáře",
    "The file contains objects incompatible with the selected calendar" : "Soubor obsahuje objekty nekompatibilní s vybraným kalendářem",
    "New calendar" : "Nový kalendář",
    "Import scheduled" : "Import načasován",
    "Settings" : "Nastavení",
    "Import calendar" : "Importovat kalendář",
    "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
    "Primary CalDAV address" : "Primární adresa CalDAV",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/cs_CZ.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendář",
    "Individual" : "Individuální",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Místnost",
    "Unknown" : "Neznámý",
    "Required" : "Vyžadován",
    "Optional" : "Nepovinně",
    "Does not attend" : "Neúčastní se",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Nacházíte se v neznámé časové zóně ({tz}), použije se UTC",
    "Please create a calendar first." : "Nejdříve prosím vytvořte kalendář.",
    "New event" : "Nová událost",
    "Attendees" : "Účastníci",
    "Reminders" : "Připomínky",
    "Repeating" : "Opakování",
    "When shared show full event" : "Po nasdílení zobrazit celou událost",
    "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
    "When shared hide this event" : "Po nasdílení skrýt tuto událost",
    "Please add a title!" : "Zadejte prosím název!",
    "Please select a calendar!" : "Vyberte prosím kalendář!",
    "Global" : "Globální",
    "None" : "Žádné",
    "Every day" : "Každý den",
    "Every week" : "Každý týden",
    "Every month" : "Každý měsíc",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "At time of event" : "V čase události",
    "5 minutes before" : "5 minut předem",
    "10 minutes before" : "10 minut předem",
    "15 minutes before" : "15 minut předem",
    "30 minutes before" : "30 minut předem",
    "1 hour before" : "1 hodinu předem",
    "2 hours before" : "2 hodiny předem",
    "Custom" : "Vlastní",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Vyskakovací",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodiny",
    "days" : "dnech",
    "week" : "týden",
    "before" : "před",
    "start" : "začátek",
    "end" : "konec",
    "Editing reminders of uknown type not supported." : "Úprava připomínek neznámého typu není podporována. ",
    "Week {number} of {year}" : "Týden {number} rok {year}",
    "Successfully imported" : "Úspěšně importován",
    "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
    "Partially imported, {n} failures" : "Částečně importován, {n} chyb",
    "Audio alarm" : "Zvuková upomínka",
    "Pop-up" : "Vyskakovací",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} před začátkem události",
    "{type} {time} before the event ends" : "{type} {time} před koncem události",
    "{type} {time} after the event starts" : "{type} {time} po začátku události",
    "{type} {time} after the event ends" : "{type} {time} po konci události",
    "{type} at the event's start" : "{type} při začátku události",
    "{type} at the event's end" : "{type} při konci události",
    "{type} at {time}" : "{type} v {time}",
    "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
    "Title of the Event" : "Název události",
    "starts" : "začíná",
    "ends" : "končí",
    "All day Event" : "Celodenní událost",
    "Location" : "Umístění",
    "Delete" : "Smazat",
    "Cancel" : "Zrušit",
    "More ..." : "Více ...",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Close" : "Zavřít",
    "Description" : "Popis",
    "Export" : "Exportovat",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prosím, kontaktujte Vašeho administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "Today" : "Dnes",
    "Share Calendar" : "Sdílet kalendář",
    "More" : "Více",
    "Edit" : "Upravit",
    "CalDAV" : "CalDAV",
    "group" : "skupina",
    "New Calendar" : "Nový kalendář",
    "Subscriptions" : "Odběry",
    "New Subscription" : "Nový odběr",
    "Url" : "URL",
    "Edit event" : "Upravit událost",
    "Delete Event" : "Smazat událost",
    "Save Event" : "Uložit událost",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relativní",
    "Absolute" : "Absolutní",
    "Repeat" : "Opakovat",
    "times every" : "krát každých",
    "Add" : "Přidat",
    "E-Mail address of attendee" : "Emailová adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pokročilých pravidel bude přidána v následujících aktualizacích.",
    "Reset repeating rule" : "Resetovat pravidlo opakování",
    "Repeat every ..." : "Opakovat každé ...",
    "end repeat ..." : "ukončit opakování ...",
    "times" : "krát",
    "Import Calendars" : "Importovat kalendáře",
    "Import canceled" : "Import zrušen",
    "Analyzing calendar" : "Analýza kalendáře",
    "The file contains objects incompatible with the selected calendar" : "Soubor obsahuje objekty nekompatibilní s vybraným kalendářem",
    "New calendar" : "Nový kalendář",
    "Import scheduled" : "Import načasován",
    "Settings" : "Nastavení",
    "Import calendar" : "Importovat kalendář",
    "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
    "Primary CalDAV address" : "Primární adresa CalDAV",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
